Learn R Programming

tsforecast (version 1.3.0)

airport: Airport Travellers Time Series.

Description

A dataset containing the total number of monthly travellers recorded in an unnamed airport between January 2013 and December 2019.

Usage

airport

Arguments

Format

A data frame with 84 rows and 2 variables:

Date

Months in which the traveller numbers are recorded.

Travellers

Total travellers in the airport of that month.

AvgTemp

Monthly average temperature (in °C) of the city where the airport is located.

AvgRain

Monthly average rain fall (in mm) in the city where the airport is located.

Examples

Run this code
data(airport)
head(airport)

Run the code above in your browser using DataLab