Learn R Programming

tsforecast (version 1.3.0)

tsmltest: McLeod-Li Test for ARCH Effect

Description

The function `tsmltest` applies the McLeod-Li test to examine whether ARCH effect exists in the squared residuals of an ARIMA model.

Usage

tsmltest(object, lag.max = NULL)

Value

A list with two elements:

test.value

chi-square test statistics of the McLeod-Li test for the lags 1 to lag.max.

p.value

corresponding p-values of the McLeod-Li test for the lags 1 to lag.max.

Arguments

object

a univariate time series object or a numeric vector or matrix.

lag.max

maximum lag at which to examine the ARCH effect. Default is NULL. Will be automatically calculated using the formula \(10\cdot \log_{10}(n)\), where \(n\) is the series length, if the parameter is omitted.

Author

Ka Yui Karl Wu

References

McLeod, A. I., & Li, W. K. (1983). Diagnostic Checking ARMA Time Series Models Using Squared-Residual Autocorrelations. Journal of Time Series Analysis, 4(4), 269-273.
tools:::Rd_expr_doi("10.1111/j.1467-9892.1983.tb00373.x").

Examples

Run this code
tsmltest(tsarima(airport$Travellers, order = c(1, 1, 0), 
                 seasonal = c(0, 1, 1), log = TRUE, include.const = TRUE))

Run the code above in your browser using DataLab