powered by
A dataset containing the total number of monthly travellers recorded in an unnamed airport between January 2013 and December 2019.
airport
A data frame with 84 rows and 2 variables:
Months in which the traveller numbers are recorded.
Total travellers in the airport of that month.
Monthly average temperature (in °C) of the city where the airport is located.
Monthly average rain fall (in mm) in the city where the airport is located.
data(airport) head(airport)
Run the code above in your browser using DataLab